pub enum MainSignalState {
Stop {
summon: bool,
},
Warning {
max_speed: Option<MaxSpeed>,
next_speed: Option<MaxSpeed>,
},
Free {
max_speed: Option<MaxSpeed>,
},
}Expand description
Possible states of a main signal.
When one really squints their eyes, a main signal only has three states:
- Stop - either a summoning signal or not
- Warning - together with an optional max speed on the next segment and an optional max speed on the next signal
- Free - together with an optional max speed on the next segment
Variants